durationtools.Offset
====================

.. inheritance-diagram:: abjad.tools.durationtools.Offset.Offset.Offset
   :private-bases:

.. autoclass:: abjad.tools.durationtools.Offset.Offset.Offset

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.denominator

   .. note:: Inherited from `fractions.Fraction`

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.imag

   .. note:: Inherited from `numbers.Real`

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.numerator

   .. note:: Inherited from `fractions.Fraction`

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.real

   .. note:: Inherited from `numbers.Real`

Methods
-------

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.conjugate

   .. note:: Inherited from `numbers.Real`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.limit_denominator

   .. note:: Inherited from `fractions.Fraction`

Special Methods
---------------

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__abs__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__add__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__complex__

   .. note:: Inherited from `numbers.Real`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__div__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__divmod__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__eq__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__float__

   .. note:: Inherited from `numbers.Rational`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__floordiv__

   .. note:: Inherited from `fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__ge__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__gt__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__hash__

   .. note:: Inherited from `fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__le__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__lt__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__mod__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__mul__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__ne__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__neg__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__nonzero__

   .. note:: Inherited from `fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__pos__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__pow__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__radd__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rdiv__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rdivmod__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__repr__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rfloordiv__

   .. note:: Inherited from `fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rmod__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rmul__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rpow__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rsub__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rtruediv__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__str__

   .. note:: Inherited from `fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__sub__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__truediv__

   .. note:: Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__trunc__

   .. note:: Inherited from `fractions.Fraction`
